/**
  *  \file client/tiles/planetnatives.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planetnatives.h"
#include "game/planet.h"
#include "ui/uiglobal.h"
#include "game/tables.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "ui/table.h"
#include "util/misc.h"
#include "ui/util.h"

/*************************** WPlanetNativeTile ***************************/

/** \class WPlanetNativeTile
    \brief Planet Native Tile

    Displays information about a planet's natives, if any. */

WPlanetNativeTile::WPlanetNativeTile(GObjectType& type)
    : WObjectTypeObserverTile(GfxPoint(315, 4 * font_heights[FONT_NORMAL]), type)
{ }

void
WPlanetNativeTile::drawData(GfxCanvas& can)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (!p)
        return;

    const int y = font_heights[FONT_NORMAL];

    setColor(UIColor::tc_Static);

    if (!p->getNativeRace()) {
        GfxRect r = getInnerSize(5, 5);
        getSkin().setSolid(false);
        getSkin().getParameters().font = fonts[FONT_NORMAL];
        drawBackground(can, GfxRect(5, 0, extent.w-5, 4*y));
        outTextFormattedF(can, getSkin(), r.x, r.y, r.w, 2,
                          _("There are no natives on this planet."));
    } else {
        // This erases the sentence from above because the table
        // writer doesn't (can't?) do that
        drawBackground(can, GfxRect(5, 0, extent.w-5, 2*y));

        UITableWriter tw(can, getSkin(), getInnerSize(5, 0), FONT_NORMAL);

        tw.newLColumn();
        tw.writeFixedCell(UIColor::tc_Static, _("Race:"));
        tw.writeFixedCell(UIColor::tc_Static, _("Population:"));
        tw.writeFixedCell(UIColor::tc_Static, _("Tax Rate:"));
        tw.writeFixedCell(UIColor::tc_Static, _("Natives are"));

        tw.newLColumn(200);
        tw.writeVariableCell(UIColor::tc_Green, string_t(getNativeRaceName(p->getNativeRace())) + ", " + getNativeGovernmentName(p->getNativeGovernment()));
        tw.writeVariableCell(UIColor::tc_Green, clansToString(p->getNatives()));
        tw.writeVariableCell(UIColor::tc_Green, format("%d%%", p->getNativeTax()));

        int happy = p->getNativeHappiness();
        UISkin::Color c = (happy <= 40
                           ? UIColor::tc_Red
                           : happy < 70
                           ? UIColor::tc_Yellow
                           : UIColor::tc_Green);
        tw.writeVariableCell(c, format("%s (%d)", getHappinessName(happy), happy));

        tw.finish();
    }
}

