/**
  *  \file client/widgets/consoleview.h
  *  \brief Console View
  */
#ifndef PCC_V2_CLIENT_WIDGETS_CONSOLEVIEW_H
#define PCC_V2_CLIENT_WIDGETS_CONSOLEVIEW_H

#include "ui/ui.h"

class Console;

/** Console view. Displays the console output. Uses the widget skin.
    Permits scrolling using external controls. */
class WConsoleView : public UIWidget {
    Console& console;
    SignalConnection conn_console;
    int display_lines;
    int scrollback_lines;

    void onUpdate(const Console& console, int added_lines);
    void limitScrollback();
 public:
    WConsoleView(Console& console, int lines);
    ~WConsoleView();

    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);

    void scrollToEnd();
    void scrollBack(int lines);
};

/** Console view with keyboard handler. Like WConsoleView, displays
    console output, but also accepts keystrokes to scroll it. */
class WConsoleViewWithHandler : public WConsoleView {
 public:
    WConsoleViewWithHandler(Console& console, int lines);
    bool handleEvent(const UIEvent& e, bool second_pass);
};

#endif
