/**
  *  \file int/if/mineif.h
  *  \brief Interpreter Game Interface: Minefields
  */
#ifndef PCC_V2_INT_IF_MINEIF_H
#define PCC_V2_INT_IF_MINEIF_H

#include "cpluslib/types.h"
#include "int/context.h"

class IntValue;
class GMinefield;
class IntDataSegment;

IntValue*   IFMinefieldGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFMinefieldMake();

/** Minefield context. */
class IntMinefieldContext : public IntContext {
    int mid;
 public:
    IntMinefieldContext(int mid);
    ~IntMinefieldContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
};

/** Minefield property identifier. */
enum IntMinefieldProperty {
    impId,
    impLastScan,
    impLocX,
    impLocY,
    impRadius,
    impScanType,
    impTypeCode,
    impTypeStr,
    impUnits
};

IntValue* getMinefieldProperty(const GMinefield& mf, IntMinefieldProperty imp);
void      setMinefieldProperty(GMinefield& mf, IntMinefieldProperty imp, IntValue* value);

#endif
