/**
  *  \file int/if/ufoif.h
  *  \brief Interpreter Game Interface: Ufo Properties
  */
#ifndef PCC_V2_INT_IF_UFOIF_H
#define PCC_V2_INT_IF_UFOIF_H

#include "int/context.h"
#include "cpluslib/types.h"
#include "game/ufo.h"

class IntValue;
class IntDataSegment;

IntValue*   IFUfoGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFUfoMake();

/** Ufo context. */
class IntUfoContext : public IntContext {
    GUfoContainer& con;
    GUfoContainer::iterator it;
 public:
    IntUfoContext(GUfoContainer& con, GUfoContainer::iterator it);
    ~IntUfoContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
};

enum IntUfoProperty {
    iupColorEGA,
    iupColorPCC,
    iupHeadingInt,
    iupHeadingName,
    iupId,
    iupId2,
    iupInfo1,
    iupInfo2,
    iupKeepFlag,
    iupLastScan,
    iupLocX,
    iupLocY,
    iupMoveDX,
    iupMoveDY,
    iupName,
    iupRadius,
    iupSpeedInt,
    iupSpeedName,
    iupType,
    iupVisiblePlanet,
    iupVisibleShip
};

IntValue* getUfoProperty(const GUfo& ufo, IntUfoProperty iup);
void      setUfoProperty(GUfo& ufo, IntUfoProperty iup, IntValue* value);

#endif
