/**
  *  \file int/simple.cc
  *  \brief Interpreter: Simple Interface
  */

#include <memory>
#include "int/simple.h"
#include "int/lex.h"
#include "int/interror.h"
#include "int/expr.h"
#include "int/parseexpr.h"

/** Compile expression, simple interface. Compiles the expression into a byte-code object.
    Returns the byte-code object, null on failure. This is used when an expression is used
    behind a regular UI function, where it doesn't really matter what kind of error, if any,
    we've encountered.

    \todo This would be a nice place to implement caching. */
IntBCORef
compileExpression(const string_t& expr, const IntCompilationContext& cc)
{
    try {
        IntTokenizer tok(expr);
        if (tok.getCurrentToken() == tok.tEnd)
            return 0; /* empty expression */

        std::auto_ptr<IntExprNode> expr(IntExpressionParser(tok).parse());
        if (tok.getCurrentToken() != tok.tEnd)
            return 0; /* expression incorrectly terminated */

        IntBCORef bco = new IntBytecodeObject();
        expr->compileValue(*bco, cc);
        return bco;
    }
    catch (IntError& e) {
        return 0;
    }
}
