/**
  *  \file tests/testexpr.cc
  */

#include <iostream>
#include "int/parseexpr.h"
#include "cpluslib/string.h"
#include "int/lex.h"
#include "cpluslib/format.h"
#include "int/exec.h"
#include "int/intglobal.h"
#include "int/if/initif.h"
#include "util/console.h"
#include "io/dirs.h"
#include "game/global.h"
#include "game/config.h"
#include "game/spec.h"
#include "game/fcode.h"
#include "game/mission.h"
#include "game/racename.h"
#include "game/coord.h"
#include "client/chartusr.h"
#include "game/team.h"
#include "game/load.h"
#include "game/stat.h"
#include "int/interror.h"


int main(int argc, char** argv)
{
    (void) argc;
    (void) argv;

    string_t line;
    initInterpreter();
    initInterpreterGameInterface(); // XXX
    enableStdioConsole();

#if 1
    if (argv[1]) {
        try {
            initGameGlobals(argv[1] ? Directory::getDirName(argv[1]) : ".", Platform::getDataDirectory());
            initConfig();
            initSpecification();
            initFCodes();
            initMissions();
            initRaceNames();
            initCoordinates();
            initStarchart();

            Ptr<Stream> pxy = spec_file_dir->openFile("xyplan.dat", Stream::C_READ);
            getCurrentTurn().init();
            getCurrentTurn().loadPlanetXY(*pxy);

            initStatisticsFile();
            initTeams();

            // HACK!
            int pid = atoi(Directory::getFileName(argv[1]).c_str() + 6);

            Ptr<Stream> rst = Stream::openFile(argv[1], Stream::C_READ);
            loadResult(getCurrentTurn(), *rst, pid);

            setPlayerIds(pid, pid);
            getCurrentTurn().postprocess();
            setDisplayedTurn(0);                // FIXME: initialize object types
            initStarchartAfterLoad();
        }
        catch (std::exception& e) {
            std::cout << "initialisation error: " << e.what() << "\n";
        }
    }
#endif

    while (getline(std::cin, line)) {
        IntTokenizer tok(line);
        IntExprNode* node = 0;
        try {
            IntExpressionParser parser(tok);
            node = parser.parse();
        }
        catch (IntError& e) {
            std::cerr << "parse error: " << e.what() << "\n";
        }
        if (node == 0) {
            // failed
        } else if (tok.getCurrentToken() != tok.tEnd) {
            std::cerr << "parse error; expression not at end\n";
        } else {
            try {
                Ptr<IntBytecodeObject> pbco = new IntBytecodeObject();
                IntBytecodeObject& bco = *pbco;
                node->compileValue(bco, IntCompilationContext().withFlags(IntCompilationContext::LocalContext | IntCompilationContext::AlsoGlobalContext));
                for (IntBytecodeObject::pc_t i = 0; i < bco.getNumInstructions(); ++i)
                    std::cout << format("%4d: <%02X.%02X.%04X>     ", i, bco(i).major, bco(i).minor, bco(i).arg)
                              << bco(i) << "\n";

                // Execute
                IntExecutionContext con;
                con.pushNewFrame(new IntExecutionFrame(pbco));
                con.run();

                IntValue* result = con.getResult();
                if (!result)
                    std::cout << "Result is null\n";
                else
                    std::cout << "Result is " << result->toString(true) << "\n";
            }
            catch (IntError& e) {
                std::cerr << "compile error: " << e.what() << "\n";
            }
        }
        delete node;
    }
}
