/**
  *  \file u/t_int.h
  *  \brief Testsuite for interpreter (int/).
  *  \ingroup Testsuite
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_U_T_INT_H
#define PCC_V2_U_T_INT_H

#include <cxxtest/TestSuite.h>

extern int32_t globalVars[3];

void checkIntExpr(const char* expr, int result);
void checkBoolExpr(const char* expr, int result);
void checkNullExpr(const char* expr);
void checkStringExpr(const char* expr, const char* result);
void checkFloatExpr(const char* expr, double result);
void checkExecFailure(const char* expr);

class IntBuiltinTestSuite : public CxxTest::TestSuite {
 public:
    void testTrig();
    void testAbs();
    void testAsc();
    void testBitOps();
    void testMinMax();
    void testChr();
    void testTypeChecks();
    void testExp();
    void testStrFind();
    void testSubstr();
    void testTrim();
    void testSqrt();
    void testRound();
    void testIf();
    void testStr();
    void testVal();
    void testZap();
    void testLen();
    void testStrMult();
    void testStrCase();
    void testAtom();
};

class IntValueTestSuite : public CxxTest::TestSuite {
 public:
    void testReal();
    void testInt();
    void testString();
};

class IntDataTestSuite : public CxxTest::TestSuite {
 public:
    void testLoad();
};

class IntLexTestSuite : public CxxTest::TestSuite {
 public:
    void testTokenizer();
    void testIntegers();
    void testFloats();
    void testStrings();
};

class IntParseExprTestSuite : public CxxTest::TestSuite {
 public:
    void setUp();
    void tearDown();

    void testLiterals();
    void testSequence();
    void testAssignment();
    void testOr();
    void testAnd();
    void testXor();
    void testNot();
    void testComparison();
    void testConcat();
    void testAdd();
    void testSubtract();
    void testMultiply();
    void testDivide();
    void testIntegerDivide();
    void testNegation();
    void testPower();
};

#endif
