/**
  *  \file ui/widgets/multilinestatic.cc
  *  \brief UIMultilineStatic widget
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/multilinestatic.h"
#include "ui/uiglobal.h"
#include "ui/util.h"
#include "ui/skin.h"

/** Constructor.
    \param font  Font to use
    \param text  Text to display
    \param width Format to this width (pixels)
    \param id    Widget id */
UIMultilineStatic::UIMultilineStatic(int font, string_t text, int width, int id)
    : UIWidget(id), font(font), text(text), width(width),
      lines(countLines(*fonts[font], width, text))
{
    setState(st_Disabled, true);
}

UIMultilineStatic::~UIMultilineStatic()
{ }

void
UIMultilineStatic::drawContent(GfxCanvas& can)
{
    GfxParameters& p = getSkin().getParameters();
    getSkin().startDraw();
    getSkin().setColor(UIColor::tc_Static);
    getSkin().setSolid(false);
    p.font = fonts[font];
    outTextFormatted(can, p, extent.x, extent.y, extent.w, text);
    can.update(getExtent());
}

void
UIMultilineStatic::getLayoutInfo(LayoutInfo& li)
{
    li.flags = 0;
    li.min_size = li.pref_size = GfxPoint(width, font_heights[font] * lines);
}

/** Change text. */
void
UIMultilineStatic::setText(string_t text)
{
    if (this->text != text) {
        this->text = text;
        lines = countLines(*fonts[font], width, text);
        drawWidget();
    }
}
